@@ -23,7 +23,7 @@ class TagField(models.TextField):
         return self.to_python(value)
 
     def to_python(self, value):
-        if isinstance(value,list):
+        if isinstance(value, list):
             return value
         if value is None:
             return []
@@ -31,15 +31,18 @@ class TagField(models.TextField):
 
     def get_db_prep_value(self, value, connection, prepared=False):
 
-        return self.delimiters.join(value)
+        return self.get_prep_value(value)
 
     def get_prep_value(self, value):
-        return self.delimiters.join(value)
+        if value:
+            return self.delimiters.join(value)
+        else:
+            return ''
 
     def formfield(self, **kwargs):
         from tagify.fields import TagField as FormTagField
-        return super(models.TextField,self).formfield(form_class=FormTagField, **self.tag_args)
+        return super(models.TextField, self).formfield(form_class=FormTagField, **self.tag_args)
 
     def value_to_string(self, obj):
         value = self.value_from_object(obj)
-        return self.get_prep_value(value)
\ No newline at end of file
+        return self.get_prep_value(value)
